@@ -273,6 +273,7 @@ int main( int argc, char *argv[] )
                  ifr.ifr_hwaddr.sa_family );
         fprintf( stderr, "expected ARPHRD_IEEE80211 or "
                  "ARPHRD_IEEE80211_PRISM\n" );
+        fprintf( stderr, "did you put your card in monitor mode ?\n" );
         return( 1 );
     }
 
@@ -350,7 +351,7 @@ int main( int argc, char *argv[] )
             {
                 if( time( NULL ) - ap_cur->tlast > 120 )
                 {
-                    ap_cur = ap_cur->next;
+                    ap_cur = ap_cur->prev;
                     continue;
                 }
 
